@@ -1112,9 +1112,10 @@ void prefs_apply_callback(GtkWidget *w, gint page, ggv_prefs *p)
         gtk_gs_defaults_set_override_orientation(GTK_TOGGLE_BUTTON(p->override_orientation)->active);
         gtk_gs_defaults_set_show_scroll_rect(GTK_TOGGLE_BUTTON(p->show_scroll_rect)->active);
 
-        ggv_panel = GTK_TOGGLE_BUTTON(p->tbar)->active;
+        ggv_panel = GTK_TOGGLE_BUTTON(p->sidebar)->active;
         ggv_save_geometry = GTK_TOGGLE_BUTTON(p->savegeo)->active;
 	ggv_toolbar = GTK_TOGGLE_BUTTON(p->toolbar)->active;
+        ggv_toolbar_labels = GTK_TOGGLE_BUTTON(p->tblabels)->active;
         ggv_menubar = GTK_TOGGLE_BUTTON(p->mbar)->active;
         ggv_auto_jump = GTK_TOGGLE_BUTTON(p->auto_jump)->active;
 
