@@ -89,6 +89,7 @@ void synchronize_orientation_items_wd(ggv_window *ggv);
 /* set visibility of components */
 void ggv_menus_set_visible(ggv_window *ggv, gboolean v);
 void ggv_toolbar_set_visible(ggv_window *ggv, gboolean v);
+void ggv_toolbar_set_labels(ggv_window *ggv, gboolean labels);
 void ggv_panel_set_visible(ggv_window *ggv, gboolean v);
 
 void set_page_sensitivities(ggv_window *ggv, int page);
@@ -170,7 +171,7 @@ struct _ggv_prefs
         GtkWidget *media, *zoom, *orientation, *units;        /* option menus */
         GtkWidget *watch, *aa, *override_media, *respect_eof, *show_scroll_rect; /* checkbuttons */
         GtkWidget *override_orientation;
-        GtkWidget *tbar, *mbar, *toolbar, *savegeo,*auto_jump;/* checkbuttons */
+        GtkWidget *sidebar, *mbar, *toolbar, *tblabels, *savegeo,*auto_jump;/* checkbuttons */
         GtkWidget **media_choice;                             /* paper items */
         GtkWidget *zoom_choice[MENU_ZOOM_SIZE];               /* zoom items */
         GtkWidget *orientation_choice[MENU_ORIENTATION_SIZE]; /* orientation items */
