@@ -156,6 +156,7 @@ static void gtk_gs_init (GtkGS *gs);
 static void gtk_gs_class_init (GtkGSClass *klass);
 static void gtk_gs_destroy (GtkObject *object);
 static void gtk_gs_realize (GtkWidget *widget);
+static void gtk_gs_unrealize (GtkWidget *widget);
 static void gtk_gs_size_request (GtkWidget *widget, GtkRequisition *requisition);
 static void gtk_gs_size_allocate (GtkWidget *widget, GtkAllocation *allocation);
 static gint gtk_gs_widget_event(GtkWidget *widget, GdkEvent *event, gpointer data);
@@ -290,6 +291,7 @@ gtk_gs_class_init (GtkGSClass *klass)
         object_class->destroy = gtk_gs_destroy;
 
         widget_class->realize       = gtk_gs_realize;
+        widget_class->unrealize     = gtk_gs_unrealize;
         widget_class->size_request  = gtk_gs_size_request;
         widget_class->size_allocate = gtk_gs_size_allocate;
 
@@ -408,6 +410,9 @@ gtk_gs_destroy (GtkObject *object)
 
         gtk_gs_cleanup(gs);
 
+	if(gs->input_buffer)
+		g_free(gs->input_buffer);
+
         for(i = 0; gs->gconf_notify_id[i] != 0; i++) {
                 gconf_client_notify_remove(gtk_gs_defaults_gconf_client(),
                                            gs->gconf_notify_id[i]);
@@ -535,6 +540,28 @@ gtk_gs_realize (GtkWidget *widget)
         gtk_gs_goto_page(gs, gs->current_page);
 }
 
+static void
+gtk_gs_unrealize (GtkWidget *widget)
+{
+        GtkGS  *gs;
+
+        g_return_if_fail (widget != NULL);
+        g_return_if_fail (GTK_IS_GS (widget));
+
+        gs = GTK_GS (widget);
+
+        if(gs->pstarget) {
+                gdk_window_destroy(gs->pstarget);
+                gs->pstarget = NULL;
+        }
+        if(gs->psgc) {
+                gdk_gc_destroy(gs->psgc);
+                gs->psgc = NULL;
+        }
+
+        if (GTK_WIDGET_CLASS (parent_class)->unrealize)
+                (* GTK_WIDGET_CLASS (parent_class)->unrealize) (widget);
+}
 
 static void
 gtk_gs_size_request (GtkWidget      *widget,
@@ -975,10 +1002,13 @@ start_interpreter (GtkGS *gs)
 	int std_in[2] = {-1, -1}; /* pipe to interp stdin */
 	int std_out[2]; /* pipe from interp stdout */
 	int std_err[2]; /* pipe from interp stderr */
-#define NUM_ARGS 100
-        char *argv[NUM_ARGS];
-        char *filename = NULL;
-        int argc = 0;
+
+#define NUM_ARGS    100
+#define NUM_GS_ARGS (NUM_ARGS - 10)
+
+        char *argv[NUM_ARGS], *dir, *gv_env;
+        char **gs_args;
+        int argc = 0, i;
 
 	if (!gs->gs_filename)
                 return 0;
@@ -987,10 +1017,21 @@ start_interpreter (GtkGS *gs)
         
 	if (gs->disable_start == TRUE)
                 return 0;
-        
+
+	/* change to directory where the input file is. This helps
+	 * with postscript-files which include other files using
+         * a relative path */
+	dir = g_dirname(gs->gs_filename);
+	chdir(dir);
+	g_free(dir);
+
         /* set up the args... */
-        argv[argc++] = gtk_gs_defaults_get_interpreter_cmd();
-        if( gs->antialiased ) 
+        gs_args = g_strsplit(gtk_gs_defaults_get_interpreter_cmd(),
+                             " ", NUM_GS_ARGS);
+        for(i = 0; i < NUM_GS_ARGS && gs_args[i]; i++, argc++)
+                argv[argc] = gs_args[i];
+
+        if(gs->antialiased ) 
 		argv[argc++] = "-sDEVICE=x11alpha";
         else 
 		argv[argc++] = "-sDEVICE=x11";
@@ -1001,8 +1042,7 @@ start_interpreter (GtkGS *gs)
 
         /* set up the pipes */
         if (gs->send_filename_to_gs) {
-                filename = g_strconcat("\"", GTK_GS_GET_PS_FILE(gs), "\"", NULL);
-                argv[argc++] = filename;
+                argv[argc++] = GTK_GS_GET_PS_FILE(gs);
                 argv[argc++] = "-c";
                 argv[argc++] = "quit";
         }
@@ -1013,22 +1053,17 @@ start_interpreter (GtkGS *gs)
 
         if (!gs->reading_from_pipe && !gs->send_filename_to_gs) {
                 if (pipe (std_in) == -1) {
-                        /* FIXME: error handling needed */
-                        g_print("Unble to open pipe to ghostview\n");
+                        g_print("Unable to open pipe to ghostview\n");
                         return -1;
                 }
         }
 	if (pipe (std_out) == -1) {
 		close_pipe(std_in);
-                if(filename)
-                        g_free(filename);
 		return -1;
 	}
 	if (pipe (std_err) == -1) {
 		close_pipe(std_in);
 		close_pipe(std_out);
-                if(filename)
-                        g_free(filename);
 		return -1;
 	}
 
@@ -1039,8 +1074,6 @@ start_interpreter (GtkGS *gs)
 		close_pipe(std_in);
 		close_pipe(std_out);
 		close_pipe(std_err);
-                if(filename)
-                        g_free(filename);
 		return -2;
 		break;
 	case 0: /* child */
@@ -1068,16 +1101,15 @@ start_interpreter (GtkGS *gs)
                         }
                 }
 
-		putenv (g_strdup_printf ("GHOSTVIEW=%ld",
-                                ((GdkWindowPrivate*)(gs->pstarget))->xwindow));
-
+                gv_env = g_strdup_printf ("GHOSTVIEW=%ld",
+                                          ((GdkWindowPrivate*)(gs->pstarget))->xwindow);
+                putenv (gv_env);
                 execvp(argv[0], argv);
                 
-                if(filename)
-                        g_free(filename);
-
                 /* Notify error */
                 g_print("Unable to execute [%s]\n", argv[0]);
+                g_strfreev(gs_args);
+                g_free(gv_env);
 		_exit(1);
 		break;
 	default: /* parent */
@@ -1163,7 +1195,7 @@ check_filecompressed (GtkGS *gs)
 	FILE *file;
 	gchar buf[1024];
 	gchar *filename, *filename_unc, *filename_err, *cmdline;
-        const gchar*cmd;
+        const gchar *cmd;
 
 	cmd = NULL;
 
@@ -1184,7 +1216,6 @@ check_filecompressed (GtkGS *gs)
 		return gs->gs_filename;
 
 	/* do the decompression */
-
 	filename = ggv_quote_filename (gs->gs_filename);
 	filename_unc = tempnam (g_get_tmp_dir(), "unc");
 	filename_err = tempnam (g_get_tmp_dir(), "err");
@@ -1198,7 +1229,7 @@ check_filecompressed (GtkGS *gs)
 	} else {
 		/* report error */
 		g_snprintf (buf, 1024, _("Error while decompressing file %s:\n"),
-			   filename);
+			   gs->gs_filename);
 		gtk_gs_emit_error_msg (gs, buf);
 		if (ggv_file_length (filename_err) > 0) {
 			FILE *err;
@@ -1516,7 +1547,16 @@ gtk_gs_load (GtkGS *gs, const gchar *fname)
  	gs->send_filename_to_gs = TRUE;
 	gs->current_page = -1;
         gs->loaded = FALSE;
-	gs->gs_filename = g_strdup (fname);
+        if(*fname == '/') {
+                /* an absolute path */
+                gs->gs_filename = g_strdup (fname);
+        }
+        else {
+                /* path relative to our cwd: make it absolute */
+                gchar *cwd = g_get_current_dir();
+                gs->gs_filename = g_strconcat(cwd, "/", fname, NULL);
+                g_free(cwd);
+        }
 
 	if ((gs->reading_from_pipe = (strcmp (fname, "-") == 0))) {
                 gs->send_filename_to_gs = FALSE;
@@ -1942,32 +1982,27 @@ gtk_gs_get_zoom(GtkGS *gs)
         return gs->zoom_factor;
 }
 
-void
-gtk_gs_zoom_to_fit(GtkGS *gs)
+gfloat
+gtk_gs_zoom_to_fit(GtkGS *gs, gboolean fit_width)
 {
         gint new_y;
         gfloat new_zoom;
 
-        g_return_if_fail(gs != NULL);
-        g_return_if_fail(GTK_IS_GS(gs));
+        g_return_val_if_fail(gs != NULL, 0.0);
+        g_return_val_if_fail(GTK_IS_GS(gs), 0.0);
         
-        new_zoom = (gfloat)gs->widget.allocation.width/(gfloat)gs->width*gs->zoom_factor;
-        new_y = new_zoom*gs->height/gs->zoom_factor;
-        if(new_y > gs->widget.allocation.height)
-                new_zoom = (gfloat)gs->widget.allocation.height/(gfloat)gs->height*gs->zoom_factor;
+	new_zoom = (gfloat)gs->widget.allocation.width/(gfloat)gs->width*gs->zoom_factor;
+	if(!fit_width) {
+		new_y = new_zoom*gs->height/gs->zoom_factor;
+		if(new_y > gs->widget.allocation.height)
+			new_zoom = (gfloat)gs->widget.allocation.height/(gfloat)gs->height*gs->zoom_factor;
+	}
 
         if(ABS(new_zoom - gs->zoom_factor) < 0.001)
-                return;
+		return 0.0;
 
-        gs->zoom_factor = new_zoom;
-
-        if(GTK_WIDGET_REALIZED (gs)) {
-                set_up_page(gs);
-                gtk_widget_queue_resize (&(gs->widget));
-                gs->changed = TRUE;
-                gtk_gs_goto_page(gs, gs->current_page);
-        }
- }
+        return new_zoom;
+}
 
 gboolean
 gtk_gs_set_default_orientation (GtkGS *gs, gint orientation) {
