@@ -1,3 +1,4 @@
+/* -*- Mode: C; tab-width: 8; indent-tabs-mode: nil; c-basic-offset: 8 -*- */
 /*
  * ps.h -- Include file for PostScript routines.
  * Copyright (C) 1992  Timothy O. Theisen
@@ -26,6 +27,9 @@
 #define __GGV_PS_H__
 
 #include <stdio.h>
+
+#include <gtkgs.h>
+
 #ifndef NeedFunctionPrototypes
 #if defined(FUNCPROTO) || defined(__STDC__) || defined(__cplusplus) || defined(c_plusplus)
 #define NeedFunctionPrototypes 1
@@ -40,86 +44,70 @@
 #define URX 2
 #define URY 3
 
-	/* Constants used to store keywords that are scanned. */
-	/* NONE is not a keyword, it tells when a field was not set */
+/* Constants used to store keywords that are scanned. */
+/* NONE is not a keyword, it tells when a field was not set */
 
 enum { ATEND = -1, NONE = 0, PORTRAIT, LANDSCAPE, ASCEND, DESCEND, SPECIAL };
 
 #define PSLINELENGTH 257	/* 255 characters + 1 newline + 1 NULL */
 
 struct document {
-    int  epsf;				/* Encapsulated PostScript flag. */
-    char *title;			/* Title of document. */
-    char *date;				/* Creation date. */
-    int  pageorder;			/* ASCEND, DESCEND, SPECIAL */
-    long beginheader, endheader;	/* offsets into file */
-    unsigned int lenheader;
-    long beginpreview, endpreview;
-    unsigned int lenpreview;
-    long begindefaults, enddefaults;
-    unsigned int lendefaults;
-    long beginprolog, endprolog;
-    unsigned int lenprolog;
-    long beginsetup, endsetup;
-    unsigned int lensetup;
-    long begintrailer, endtrailer;
-    unsigned int lentrailer;
-    int  boundingbox[4];
-    int  default_page_boundingbox[4];
-    int  orientation;			/* PORTRAIT, LANDSCAPE */
-    int  default_page_orientation;	/* PORTRAIT, LANDSCAPE */
-    unsigned int nummedia;
-    struct documentmedia *media;
-    struct documentmedia *default_page_media;
-    unsigned int numpages;
-    struct page *pages;
+        int  epsf;				/* Encapsulated PostScript flag. */
+        char *title;			/* Title of document. */
+        char *date;				/* Creation date. */
+        int  pageorder;			/* ASCEND, DESCEND, SPECIAL */
+        long beginheader, endheader;	/* offsets into file */
+        unsigned int lenheader;
+        long beginpreview, endpreview;
+        unsigned int lenpreview;
+        long begindefaults, enddefaults;
+        unsigned int lendefaults;
+        long beginprolog, endprolog;
+        unsigned int lenprolog;
+        long beginsetup, endsetup;
+        unsigned int lensetup;
+        long begintrailer, endtrailer;
+        unsigned int lentrailer;
+        int  boundingbox[4];
+        int  default_page_boundingbox[4];
+        int  orientation;			/* PORTRAIT, LANDSCAPE */
+        int  default_page_orientation;	/* PORTRAIT, LANDSCAPE */
+        unsigned int nummedia;
+        GtkGSPaperSize *media;
+        GtkGSPaperSize *default_page_media;
+        unsigned int numpages;
+        struct page *pages;
 };
 
 struct page {
-    char *label;
-    int  boundingbox[4];
-    struct documentmedia *media;
-    int  orientation;			/* PORTRAIT, LANDSCAPE */
-    long begin, end;			/* offsets into file */
-    unsigned int len;
+        char *label;
+        int  boundingbox[4];
+        GtkGSPaperSize *media;
+        int  orientation;			/* PORTRAIT, LANDSCAPE */
+        long begin, end;			/* offsets into file */
+        unsigned int len;
 };
 
-struct documentmedia {
-    char *name;
-    int width, height;
-};
-
-	/* list of standard paper sizes from Adobe's PPD. */
-#define PAPER_SIZE_COUNT 16
-extern struct documentmedia papersizes[PAPER_SIZE_COUNT+1];
-
-	/* scans a PostScript file and return a pointer to the document
-	   structure.  Returns NULL if file does not Conform to commenting
-	   conventions . */
-
+/* scans a PostScript file and return a pointer to the document
+   structure.  Returns NULL if file does not Conform to commenting
+   conventions . */
 struct document *psscan(FILE *fileP, int respect_eof);
 
-	/* free data structure malloc'ed by psscan */
-
-
+/* free data structure malloc'ed by psscan */
 void psfree(struct document *);
 
-
-	/* Copy a portion of the PostScript file */
-
+/* Copy a portion of the PostScript file */
 #if NeedFunctionPrototypes
 void pscopy(FILE *from, FILE *to, long begin, long end);
 #else
 void pscopy();
 #endif
 
-	/* Copy a portion of the PostScript file upto a comment */
-
+/* Copy a portion of the PostScript file upto a comment */
 char *pscopyuntil(FILE *from, FILE *to, long begin, long end,
 		  const char *comment);
 
-        /* Copy the headers, marked pages, and trailer to fp */
-
+/* Copy the headers, marked pages, and trailer to fp */
 #if NeedFunctionPrototypes
 void pscopydoc(FILE *dest_file, char *src_filename,
 	       struct document *d, int *pagelist);
